summaryrefslogtreecommitdiffstats
path: root/src/interface.cpp
diff options
context:
space:
mode:
authorAlex Valavanis <valavanisalex@gmail.com>2014-01-03 10:33:30 +0000
committerAlex Valavanis <valavanisalex@gmail.com>2014-01-03 10:33:30 +0000
commit25bea5005bdd07e3807c04ce7942786571344ac2 (patch)
treeecca5d707b9e861aab0be8a51159e053e9773221 /src/interface.cpp
parentfix pointer initialization ( "0" --> "NULL") (diff)
downloadinkscape-25bea5005bdd07e3807c04ce7942786571344ac2.tar.gz
inkscape-25bea5005bdd07e3807c04ce7942786571344ac2.zip
Stop using GTK_IS_HBOX: Deprecated in Gtk+ 3
(bzr r12872)
Diffstat (limited to 'src/interface.cpp')
-rw-r--r--src/interface.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/interface.cpp b/src/interface.cpp
index 881dbbc0c..bdbedd311 100644
--- a/src/interface.cpp
+++ b/src/interface.cpp
@@ -1418,13 +1418,13 @@ sp_ui_menu_item_set_name(GtkWidget *data, Glib::ustring const &name)
if (data || GTK_IS_BIN (data)) {
void *child = gtk_bin_get_child (GTK_BIN (data));
//child is either
//- a GtkHBox, whose first child is a label displaying name if the menu
//item has an accel key
//- a GtkLabel if the menu has no accel key
if (child != NULL){
if (GTK_IS_LABEL(child)) {
gtk_label_set_markup_with_mnemonic(GTK_LABEL (child), name.c_str());
- } else if (GTK_IS_HBOX(child)) {
+ } else if (GTK_IS_BOX(child)) {
gtk_label_set_markup_with_mnemonic(
GTK_LABEL (gtk_container_get_children(GTK_CONTAINER (child))->data),
name.c_str());
@@ -1418,13 +1418,13 @@ sp_ui_menu_item_set_name(GtkWidget *data, Glib::ustring const &name)
void *child = gtk_bin_get_child (GTK_BIN (data));
//child is either
- //- a GtkHBox, whose first child is a label displaying name if the menu
+ //- a GtkBox, whose first child is a label displaying name if the menu
//item has an accel key
//- a GtkLabel if the menu has no accel key